import './button-inspector-controls.scss';

import React from 'react';
import { SelectControl, PanelBody, Card, CardBody } from '@wordpress/components';

import { InspectorControls } from '@wordpress/block-editor';
import { __ } from '@wordpress/i18n';

import TypographyControls from '../TypographyControls/TypographyControls';
import SpacingControls from '../SpacingControls/SpacingControls';
import ColorControls from '../ColorControls/ColorControls';
import IconControls from '../IconControls/IconControls';
import DownloadInput from '../DownloadInput/DownloadInput';
import VersionInput from '../VersionInput/VersionInput';

export default function ButtonInspectorControls({
	attributes,
	setAttributes,
	downloads,
	templates,
}) {
	const { id, template, version_id } = attributes;

	const handleAfterAttributeClick = (e) => {
		let attr = e.target.dataset.attribute;
		setAttributes({
			[attr]: { ...attributes[attr], after: e.target.value },
		});
	};

	const handleSyncPress = (e) => {
		let attr = e.target.dataset.attribute;
		let max = Math.max(
			attributes[attr].top,
			attributes[attr].bottom,
			attributes[attr].left,
			attributes[attr].right
		);
		setAttributes({
			[attr]: {
				...attributes[attr],
				sync: !attributes[attr].sync,
				top: max,
				bottom: max,
				left: max,
				right: max,
			},
		});
	};

	return (
		<InspectorControls>
			<PanelBody
				title={__('Select a download...', 'dlm-buttons')}
				initialOpen={true}
			>
				<DownloadInput
					onChange={ ( v ) =>
						setAttributes( { id: v } )
					}
					selectedDownloadId={id}
					value={id}
				/>
			</PanelBody>
			{id != 0 && (
				<PanelBody
					title={__('Select a version...', 'dlm-buttons')}
					initialOpen={true}
				>
					<VersionInput
						selectedVersionId={version_id}
						downloadId={id}
						onChange={(v) =>
							setAttributes({ version_id: parseInt(v) })
						}
					/>
				</PanelBody>
			)}

			<PanelBody
				title={__('Select a template...', 'dlm-buttons')}
				initialOpen={true}
			>
				<SelectControl
					value={template}
					options={templates}
					onChange={(t) => setAttributes({ template: t })}
				/>
				{template != 'none' && (
					<em>
						{__(
							"Dont't worry about the %% tags not showing up, it will be rendered on the front end.",
							'dlm-buttons'
						)}
					</em>
				)}
			</PanelBody>
			{template == 'none' && (
				<>
					<TypographyControls
						attributes={attributes}
						setAttributes={setAttributes}
					/>
					<SpacingControls
						attributes={attributes}
						setAttributes={setAttributes}
						handleAfterAttributeClick={handleAfterAttributeClick}
						handleSyncPress={handleSyncPress}
					/>
					<ColorControls
						attributes={attributes}
						setAttributes={setAttributes}
					/>
					<IconControls
						attributes={attributes}
						setAttributes={setAttributes}
						handleAfterAttributeClick={handleAfterAttributeClick}
						handleSyncPress={handleSyncPress}
					/>
				</>
			)}

			<Card>
				<CardBody>
				{__(
						"Available variables are:",
							'dlm-buttons'
						)}
					<ul>
						<li>
							<code>%name%</code> - {__('Download name', 'dlm-buttons')}
						</li>
						<li>
							<code>%version%</code> - {__('Download version', 'dlm-buttons')}
						</li>
						<li>
							<code>%filename%</code> - {__('File name', 'dlm-buttons')}
						</li>
						<li>
							<code>%filesize%</code> - {__('File size', 'dlm-buttons')}
						</li>
						<li>
							<code>%download_count%</code> - {__('Download count', 'dlm-buttons')}
						</li>
					</ul>
				</CardBody>
			</Card>
		</InspectorControls>
	);
}
