import './colorcontrols.scss';

import React, { useState } from 'react';

import {
	PanelBody,
	BaseControl,
	Button,
	ButtonGroup,
	ColorPalette,
} from '@wordpress/components';

import { icons } from '../icons';
import { __ } from '@wordpress/i18n';

export default function ColorControls({ attributes, setAttributes }) {
	const { colors } = attributes;
	const [isHoverTab, setIsHoverTab] = useState(false);

	const handleColorChange = (color, type) => {
		setAttributes({ colors: { ...colors, [type]: color } });
	};
	return (
		<>
			<PanelBody
				title={__('Colors', 'dlm-buttons')}
				icon={icons.colors}
				className="dlm-buttons-panel"
				initialOpen={false}
			>
				<ButtonGroup className="dlm-buttons-tabs">
					<Button
						className={!isHoverTab ? 'is-pressed' : ''}
						onClick={() => setIsHoverTab(false)}
						isSmall
					>
						Normal
					</Button>
					<Button
						className={isHoverTab ? 'is-pressed' : ''}
						onClick={() => setIsHoverTab(true)}
						isSmall
					>
						Hover
					</Button>
				</ButtonGroup>
				{!isHoverTab ? (
					<>
						<BaseControl
							className="dlm-buttons-color"
							label={__('Background Color', 'dlm-buttons')}
						>
							<ColorPalette
								className="dlm-buttons-color-picker"
								value={attributes.colors.backgroundColor}
								enableAlpha
								clearable={false}
								onChange={(color) =>
									handleColorChange(color, 'backgroundColor')
								}
							/>
						</BaseControl>
						<BaseControl
							className="dlm-buttons-color"
							label={__('Text Color', 'dlm-buttons')}
						>
							<ColorPalette
								className="dlm-buttons-color-picker"
								value={attributes.colors.textColor}
								enableAlpha
								clearable={false}
								onChange={(color) =>
									handleColorChange(color, 'textColor')
								}
							/>
						</BaseControl>
						<BaseControl
							className="dlm-buttons-color"
							label={__('Border Color', 'dlm-buttons')}
						>
							<ColorPalette
								className="dlm-buttons-color-picker"
								value={attributes.colors.borderColor}
								enableAlpha
								clearable={false}
								onChange={(color) =>
									handleColorChange(color, 'borderColor')
								}
							/>
						</BaseControl>
						<BaseControl
							className="dlm-buttons-color"
							label={__('Icon Color', 'dlm-buttons')}
						>
							<ColorPalette
								className="dlm-buttons-color-picker"
								value={attributes.colors.iconColor}
								enableAlpha
								clearable={false}
								defaultValue="#ffffff"
								onChange={(color) =>
									handleColorChange(color, 'iconColor')
								}
							/>
						</BaseControl>
					</>
				) : (
					<>
						<BaseControl
							className="dlm-buttons-color"
							label={__('Background Color', 'dlm-buttons')}
						>
							<ColorPalette
								className="dlm-buttons-color-picker"
								value={attributes.colors.hoverBackgroundColor}
								enableAlpha
								clearable={false}
								onChange={(color) =>
									handleColorChange(
										color,
										'hoverBackgroundColor'
									)
								}
							/>
						</BaseControl>
						<BaseControl
							className="dlm-buttons-color"
							label={__('Text Color', 'dlm-buttons')}
						>
							<ColorPalette
								className="dlm-buttons-color-picker"
								value={attributes.colors.hoverTextColor}
								enableAlpha
								clearable={false}
								onChange={(color) =>
									handleColorChange(color, 'hoverTextColor')
								}
							/>
						</BaseControl>
						<BaseControl
							className="dlm-buttons-color"
							label={__('Border Color', 'dlm-buttons')}
						>
							<ColorPalette
								className="dlm-buttons-color-picker"
								value={attributes.colors.hoverBorderColor}
								enableAlpha
								clearable={false}
								onChange={(color) =>
									handleColorChange(color, 'hoverBorderColor')
								}
							/>
						</BaseControl>
						<BaseControl
							className="dlm-buttons-color"
							label={__('Icon Color', 'dlm-buttons')}
						>
							<ColorPalette
								className="dlm-buttons-color-picker"
								value={attributes.colors.hoverIconColor}
								enableAlpha
								clearable={false}
								onChange={(color) =>
									handleColorChange(color, 'hoverIconColor')
								}
							/>
						</BaseControl>
					</>
				)}
			</PanelBody>
		</>
	);
}
