import './download-button.scss';

import React from 'react';
import { RichText } from '@wordpress/block-editor';
import DOMPurify, { sanitize } from 'dompurify';

export default function DownloadButton({
	attributes,
	setAttributes,
	buttonId,
}) {
	return (
		<>
			<style
				dangerouslySetInnerHTML={{
					__html: `
								.dlm-buttons-button-${buttonId}:hover {
									cursor: pointer;
									background-color: ${attributes.colors.hoverBackgroundColor};
									color: ${attributes.colors.hoverTextColor};
									border-color: ${attributes.colors.hoverBorderColor}!important;
								}

								.dlm-buttons-button-${buttonId} {
									background-color: ${attributes.colors.backgroundColor};
									color: ${attributes.colors.textColor};
									border-color: ${attributes.colors.borderColor}!important;
								}

								.dlm-buttons-button-${buttonId}:hover .dlm-icon, .dlm-buttons-button-${buttonId}:hover .dlm-icon svg {
									color: ${attributes.colors.hoverIconColor};
									fill: ${attributes.colors.hoverIconColor};
								}

								.dlm-buttons-button-${buttonId} .dlm-icon, .dlm-buttons-button-${buttonId} .dlm-icon svg {
									color: ${attributes.colors.iconColor};
									fill: ${attributes.colors.iconColor};
									width: ${attributes.iconSize.size}${attributes.iconSize.after};
									font-size: ${attributes.iconSize.size}${attributes.iconSize.after};
									height: auto;
								}

								.dlm-buttons-button-${buttonId} .dlm-icon {
									padding: ${attributes.iconPadding.top}${attributes.iconPadding.after} ${attributes.iconPadding.right}${attributes.iconPadding.after} ${attributes.iconPadding.bottom}${attributes.iconPadding.after} ${attributes.iconPadding.left}${attributes.iconPadding.after};
								}
							`,
				}}
			/>
			<button
				style={{
					padding: `${attributes.padding.top}${attributes.padding.after} ${attributes.padding.right}${attributes.padding.after} ${attributes.padding.bottom}${attributes.padding.after} ${attributes.padding.left}${attributes.padding.after}`,
					margin: `${attributes.margin.top}${attributes.margin.after} ${attributes.margin.right}${attributes.margin.after} ${attributes.margin.bottom}${attributes.margin.after} ${attributes.margin.left}${attributes.margin.after}`,
					borderTop: `${attributes.borderSize.top}${attributes.borderSize.after} solid`,
					borderRight: `${attributes.borderSize.right}${attributes.borderSize.after} solid`,
					borderBottom: `${attributes.borderSize.bottom}${attributes.borderSize.after} solid`,
					borderLeft: `${attributes.borderSize.left}${attributes.borderSize.after} solid`,
					borderRadius: `${attributes.borderRadius.top}${attributes.borderRadius.after} ${attributes.borderRadius.right}${attributes.borderRadius.after} ${attributes.borderRadius.bottom}${attributes.borderRadius.after} ${attributes.borderRadius.left}${attributes.borderRadius.after}`,
					display: 'flex',
					alignItems: 'center',
					fontFamily: attributes.font.fontFamily,
					fontSize: `${attributes.font.fontSize}${attributes.font.after}`,
					fontWeight: attributes.font.fontWeight,
					textTransform: attributes.font.textTransform,
				}}
				className={`dlm-buttons-button-${buttonId} dlm-buttons-button ${
					attributes.iconPosition == 'right' ? 'is-right-icon' : ''
				}`}
				id={buttonId}
			>
				{attributes.icon !== '' && (
					<span
						className="dlm-icon"
						dangerouslySetInnerHTML={{
							__html: sanitize(attributes.icon, {
								USE_PROFILES: { svg: true, svgFilters: true },
							}),
						}}
					/>
				)}

				{!attributes.removeText && (
					<RichText
						tagName="span"
						withoutInteractiveFormatting="true"
						value={attributes.title}
						onChange={(title) => setAttributes({ title: title })}
					/>
				)}
			</button>
		</>
	);
}
