import './icon-controls.scss';

import React from 'react';
import {
	PanelBody,
	TextControl,
	SelectControl,
	ButtonGroup,
	Button,
	BaseControl,
	ToggleControl,
} from '@wordpress/components';

import DOMPurify, { sanitize } from 'dompurify';

import { icons } from '../icons';
import { __ } from '@wordpress/i18n';

import IconPopover from '../IconPopover';

export default function IconControls({
	attributes,
	setAttributes,
	handleAfterAttributeClick,
	handleSyncPress,
}) {
	const { iconPadding, iconSize } = attributes;

	const locationOptions = [
		{ label: __('Left', 'dlm-buttons'), value: 'left' },
		{ label: __('Right', 'dlm-buttons'), value: 'right' },
	];

	const handleSyncIconPaddingValue = (value) => {
		if (value < 0) return;
		setAttributes({
			iconPadding: {
				...iconPadding,
				top: value,
				right: value,
				bottom: value,
				left: value,
			},
		});
	};

	const handleIconAfterClick = (e) => {
		setAttributes({ iconSize: { ...iconSize, after: e.target.value } });
	};

	const handleResetClick = () => {
		setAttributes({
			iconSize: {
				size: 24,
				after: 'px',
			},
		});
	};

	const handleIconSizeChange = (e) => {
		if (e < 0) return;
		setAttributes({ iconSize: { ...iconSize, size: e } });
	};
	return (
		<>
			<PanelBody
				title={__('Icons', 'dlm-buttons')}
				icon={icons.info}
				className="dlm-buttons-panel"
				initialOpen={false}
			>
				<TextControl
					label={__('Icon SVG HTML', 'dlm-buttons')}
					value={attributes.icon}
					onChange={(value) => {
						setAttributes({
							icon: sanitize(value, {
								USE_PROFILES: { svg: true, svgFilters: true },
							}),
						});
						setAttributes({ hasIcon: true });
					}}
				/>
				{attributes.hasIcon && (
					<div
						className="dlm-buttons-icon-preview"
						style={{
							width: '24px',
							height: '24px',
							marginBottom: '0.25em',
						}}
					>
						<span
							dangerouslySetInnerHTML={{
								__html: sanitize(attributes.icon, {
									USE_PROFILES: {
										svg: true,
										svgFilters: true,
									},
								}),
							}}
						></span>
						<Button
							onClick={() =>
								setAttributes({
									hasIcon: false,
									icon: '',
								})
							}
							isSmall
							isPrimary
						>
							{__('Clear', 'dlm-buttons')}
						</Button>
					</div>
				)}
				<PanelBody
					title={__('Dashicons', 'dlm-buttons')}
					initialOpen={false}
					className="dlm-dashicons-panel"
				>
					<IconPopover
						icon={attributes.icon}
						setAttributes={setAttributes}
					/>
				</PanelBody>
				<SelectControl
					options={locationOptions}
					value={attributes.iconPosition}
					label={__('Icon Position', 'dlm-buttons')}
					onChange={(value) => {
						setAttributes({ iconPosition: value });
					}}
				/>

				<ToggleControl
					label={__('Remove Text', 'dlm-buttons')}
					checked={attributes.removeText}
					onChange={() =>
						setAttributes({ removeText: !attributes.removeText })
					}
				/>

				<div className="dlm-buttons-unit-controls">
					<p>{__('Padding', 'dlm-buttons')}</p>
					<ButtonGroup>
						<Button
							className={
								'px' == iconPadding.after ? 'is-pressed' : ''
							}
							value="px"
							data-attribute="iconPadding"
							onClick={handleAfterAttributeClick}
							isSmall
						>
							px
						</Button>
						<Button
							className={
								'em' == iconPadding.after ? 'is-pressed' : ''
							}
							value="em"
							data-attribute="iconPadding"
							onClick={handleAfterAttributeClick}
							isSmall
						>
							em
						</Button>
					</ButtonGroup>
				</div>
				<BaseControl className="dlm-buttons-column-control-multiple">
					<div className="dlm-buttons-input-group">
						<TextControl
							type="number"
							value={iconPadding.top}
							help={__('Top', 'dlm-buttons')}
							onChange={(value) => {
								if (iconPadding.sync) {
									handleSyncIconPaddingValue(value);
								} else {
									setAttributes({
										iconPadding: {
											...iconPadding,
											top: value,
										},
									});
								}
							}}
						/>
						<TextControl
							type="number"
							value={iconPadding.bottom}
							help={__('Bottom', 'dlm-buttons')}
							onChange={(value) => {
								if (iconPadding.sync) {
									handleSyncIconPaddingValue(value);
								} else {
									setAttributes({
										iconPadding: {
											...iconPadding,
											bottom: value,
										},
									});
								}
							}}
						/>
						<TextControl
							type="number"
							value={iconPadding.left}
							help={__('Left', 'dlm-buttons')}
							onChange={(value) => {
								if (iconPadding.sync) {
									handleSyncIconPaddingValue(value);
								} else {
									setAttributes({
										iconPadding: {
											...iconPadding,
											left: value,
										},
									});
								}
							}}
						/>
						<TextControl
							type="number"
							value={iconPadding.right}
							help={__('Right', 'dlm-buttons')}
							onChange={(value) => {
								if (iconPadding.sync) {
									handleSyncIconPaddingValue(value);
								} else {
									setAttributes({
										iconPadding: {
											...iconPadding,
											right: value,
										},
									});
								}
							}}
						/>
					</div>
					<Button
						className={iconPadding.sync ? 'is-pressed' : ''}
						data-attribute={'iconPadding'}
						icon={icons.sync}
						onClick={(e) => handleSyncPress(e)}
					/>
				</BaseControl>
				<BaseControl className="dlm-buttons-controls">
					<div className="dlm-buttons-unit-controls">
						<BaseControl.VisualLabel>
							{__('Icon Size', 'dlm-buttons')}
						</BaseControl.VisualLabel>
						<ButtonGroup>
							<Button
								className={
									'px' == iconSize.after ? 'is-pressed' : ''
								}
								value="px"
								onClick={handleIconAfterClick}
								isSmall
							>
								px
							</Button>
							<Button
								className={
									'em' == iconSize.after ? 'is-pressed' : ''
								}
								value="em"
								onClick={handleIconAfterClick}
								isSmall
							>
								em
							</Button>
							<Button
								className={
									'%' == iconSize.after ? 'is-pressed' : ''
								}
								value="%"
								onClick={handleIconAfterClick}
								isSmall
							>
								%
							</Button>
						</ButtonGroup>
					</div>
					<div className="dlm-buttons-input-controls">
						<TextControl
							placeholder={iconSize.fontSize}
							value={iconSize.fontSize}
							onChange={(e) => handleIconSizeChange(e)}
							type="number"
						/>
						<Button onClick={handleResetClick} isSmall isSecondary>
							Reset
						</Button>
					</div>
				</BaseControl>
			</PanelBody>
		</>
	);
}
