import './spacingcontrols.scss';

import React from 'react';
import {
	PanelBody,
	BaseControl,
	Button,
	ButtonGroup,
	TextControl,
} from '@wordpress/components';

import { icons } from '../icons';
import { __ } from '@wordpress/i18n';

export default function SpacingControls({
	attributes,
	setAttributes,
	handleAfterAttributeClick,
	handleSyncPress,
}) {
	const { padding, margin, borderSize, borderRadius } = attributes;

	const handleSyncPadding = (value) => {
		if (value < 0) return;
		setAttributes({
			padding: {
				...padding,
				top: value,
				right: value,
				bottom: value,
				left: value,
			},
		});
	};

	const handleSyncMargin = (value) => {
		if (value < 0) return;
		setAttributes({
			margin: {
				...margin,
				top: value,
				right: value,
				bottom: value,
				left: value,
			},
		});
	};

	const handleSyncBorderSize = (value) => {
		if (value < 0) return;
		setAttributes({
			borderSize: {
				...borderSize,
				top: value,
				right: value,
				bottom: value,
				left: value,
			},
		});
	};

	const handleSyncBorderRadius = (value) => {
		if (value < 0) return;
		setAttributes({
			borderRadius: {
				...borderRadius,
				top: value,
				right: value,
				bottom: value,
				left: value,
			},
		});
	};
	return (
		<>
			<PanelBody
				className="dlm-buttons-panel"
				icon={icons.spacing}
				title={__('Spacing', 'dlm-buttons')}
				initialOpen={false}
			>
				<div className="dlm-buttons-unit-controls">
					<p>{__('Padding', 'dlm-buttons')}</p>
					<ButtonGroup>
						<Button
							className={
								'px' == padding.after ? 'is-pressed' : ''
							}
							value="px"
							data-attribute="padding"
							onClick={handleAfterAttributeClick}
							isSmall
						>
							px
						</Button>
						<Button
							className={
								'em' == padding.after ? 'is-pressed' : ''
							}
							value="em"
							data-attribute="padding"
							onClick={handleAfterAttributeClick}
							isSmall
						>
							em
						</Button>
						<Button
							className={'%' == padding.after ? 'is-pressed' : ''}
							value="%"
							data-attribute="padding"
							onClick={handleAfterAttributeClick}
							isSmall
						>
							%
						</Button>
					</ButtonGroup>
				</div>
				<BaseControl className="dlm-buttons-column-control-multiple">
					<div className="dlm-buttons-input-group">
						<TextControl
							type="number"
							value={padding.top}
							help={__('Top', 'dlm-buttons')}
							onChange={(value) => {
								if (padding.sync) {
									handleSyncPadding(value);
								} else {
									setAttributes({
										padding: { ...padding, top: value },
									});
								}
							}}
						/>
						<TextControl
							type="number"
							value={padding.bottom}
							help={__('Bottom', 'dlm-buttons')}
							onChange={(value) => {
								if (padding.sync) {
									handleSyncPadding(value);
								} else {
									setAttributes({
										padding: { ...padding, bottom: value },
									});
								}
							}}
						/>
						<TextControl
							type="number"
							value={padding.left}
							help={__('Left', 'dlm-buttons')}
							onChange={(value) => {
								if (padding.sync) {
									handleSyncPadding(value);
								} else {
									setAttributes({
										padding: { ...padding, left: value },
									});
								}
							}}
						/>
						<TextControl
							type="number"
							value={padding.right}
							help={__('Right', 'dlm-buttons')}
							onChange={(value) => {
								if (padding.sync) {
									handleSyncPadding(value);
								} else {
									setAttributes({
										padding: { ...padding, right: value },
									});
								}
							}}
						/>
					</div>
					<Button
						className={attributes.padding.sync ? 'is-pressed' : ''}
						data-attribute={'padding'}
						icon={icons.sync}
						onClick={(e) => handleSyncPress(e)}
					/>
				</BaseControl>

				<div className="dlm-buttons-unit-controls">
					<p>{__('Margin', 'dlm-buttons')}</p>
					<ButtonGroup>
						<Button
							className={'px' == margin.after ? 'is-pressed' : ''}
							value="px"
							data-attribute="margin"
							onClick={handleAfterAttributeClick}
							isSmall
						>
							px
						</Button>
						<Button
							className={'em' == margin.after ? 'is-pressed' : ''}
							value="em"
							data-attribute="margin"
							onClick={handleAfterAttributeClick}
							isSmall
						>
							em
						</Button>
						<Button
							className={'%' == margin.after ? 'is-pressed' : ''}
							value="%"
							data-attribute="margin"
							onClick={handleAfterAttributeClick}
							isSmall
						>
							%
						</Button>
					</ButtonGroup>
				</div>
				<BaseControl className="dlm-buttons-column-control-multiple">
					<div className="dlm-buttons-input-group">
						<TextControl
							type="number"
							value={margin.top}
							help={__('Top', 'dlm-buttons')}
							onChange={(value) => {
								if (margin.sync) {
									handleSyncMargin(value);
								} else {
									setAttributes({
										margin: { ...margin, top: value },
									});
								}
							}}
						/>
						<TextControl
							type="number"
							value={margin.bottom}
							help={__('Bottom', 'dlm-buttons')}
							onChange={(value) => {
								if (margin.sync) {
									handleSyncMargin(value);
								} else {
									setAttributes({
										margin: { ...margin, bottom: value },
									});
								}
							}}
						/>
						<TextControl
							type="number"
							value={margin.left}
							help={__('Left', 'dlm-buttons')}
							onChange={(value) => {
								if (margin.sync) {
									handleSyncMargin(value);
								} else {
									setAttributes({
										margin: { ...margin, left: value },
									});
								}
							}}
						/>
						<TextControl
							type="number"
							value={margin.right}
							help={__('Right', 'dlm-buttons')}
							onChange={(value) => {
								if (margin.sync) {
									handleSyncMargin(value);
								} else {
									setAttributes({
										margin: { ...margin, right: value },
									});
								}
							}}
						/>
					</div>
					<Button
						className={margin.sync ? 'is-pressed' : ''}
						data-attribute={'margin'}
						icon={icons.sync}
						onClick={(e) => handleSyncPress(e)}
					/>
				</BaseControl>

				<div className="dlm-buttons-unit-controls">
					<p>{__('Border Size', 'dlm-buttons')}</p>
					<ButtonGroup>
						<Button
							className={
								'px' == borderSize.after ? 'is-pressed' : ''
							}
							value="px"
							data-attribute="borderSize"
							onClick={handleAfterAttributeClick}
							isSmall
						>
							px
						</Button>
						<Button
							className={
								'em' == borderSize.after ? 'is-pressed' : ''
							}
							value="em"
							data-attribute="borderSize"
							onClick={handleAfterAttributeClick}
							isSmall
						>
							em
						</Button>
						<Button
							className={
								'%' == borderSize.after ? 'is-pressed' : ''
							}
							value="%"
							data-attribute="borderSize"
							onClick={handleAfterAttributeClick}
							isSmall
						>
							%
						</Button>
					</ButtonGroup>
				</div>
				<BaseControl className="dlm-buttons-column-control-multiple">
					<div className="dlm-buttons-input-group">
						<TextControl
							type="number"
							value={borderSize.top}
							help={__('Top', 'dlm-buttons')}
							onChange={(value) => {
								if (borderSize.sync) {
									handleSyncBorderSize(value);
								} else {
									setAttributes({
										borderSize: {
											...borderSize,
											top: value,
										},
									});
								}
							}}
						/>
						<TextControl
							type="number"
							value={borderSize.bottom}
							help={__('Bottom', 'dlm-buttons')}
							onChange={(value) => {
								if (borderSize.sync) {
									handleSyncBorderSize(value);
								} else {
									setAttributes({
										borderSize: {
											...borderSize,
											bottom: value,
										},
									});
								}
							}}
						/>
						<TextControl
							type="number"
							value={borderSize.left}
							help={__('Left', 'dlm-buttons')}
							onChange={(value) => {
								if (borderSize.sync) {
									handleSyncBorderSize(value);
								} else {
									setAttributes({
										borderSize: {
											...borderSize,
											left: value,
										},
									});
								}
							}}
						/>
						<TextControl
							type="number"
							value={borderSize.right}
							help={__('Right', 'dlm-buttons')}
							onChange={(value) => {
								if (borderSize.sync) {
									handleSyncBorderSize(value);
								} else {
									setAttributes({
										borderSize: {
											...borderSize,
											right: value,
										},
									});
								}
							}}
						/>
					</div>
					<Button
						className={borderSize.sync ? 'is-pressed' : ''}
						data-attribute={'borderSize'}
						icon={icons.sync}
						onClick={(e) => handleSyncPress(e)}
					/>
				</BaseControl>

				<div className="dlm-buttons-unit-controls">
					<p>{__('Border Radius', 'dlm-buttons')}</p>
					<ButtonGroup>
						<Button
							className={
								'px' == borderRadius.after ? 'is-pressed' : ''
							}
							value="px"
							data-attribute="borderRadius"
							onClick={handleAfterAttributeClick}
							isSmall
						>
							px
						</Button>
						<Button
							className={
								'em' == borderRadius.after ? 'is-pressed' : ''
							}
							value="em"
							data-attribute="borderRadius"
							onClick={handleAfterAttributeClick}
							isSmall
						>
							em
						</Button>
						<Button
							className={
								'%' == borderRadius.after ? 'is-pressed' : ''
							}
							value="%"
							data-attribute="borderRadius"
							onClick={handleAfterAttributeClick}
							isSmall
						>
							%
						</Button>
					</ButtonGroup>
				</div>
				<BaseControl className="dlm-buttons-column-control-multiple">
					<div className="dlm-buttons-input-group">
						<TextControl
							type="number"
							value={borderRadius.top}
							help={__('Top', 'dlm-buttons')}
							onChange={(value) => {
								if (borderRadius.sync) {
									handleSyncBorderRadius(value);
								} else {
									setAttributes({
										borderRadius: {
											...borderRadius,
											top: value,
										},
									});
								}
							}}
						/>
						<TextControl
							type="number"
							value={borderRadius.bottom}
							help={__('Bottom', 'dlm-buttons')}
							onChange={(value) => {
								if (borderRadius.sync) {
									handleSyncBorderRadius(value);
								} else {
									setAttributes({
										borderRadius: {
											...borderRadius,
											bottom: value,
										},
									});
								}
							}}
						/>
						<TextControl
							type="number"
							value={borderRadius.left}
							help={__('Left', 'dlm-buttons')}
							onChange={(value) => {
								if (borderRadius.sync) {
									handleSyncBorderRadius(value);
								} else {
									setAttributes({
										borderRadius: {
											...borderRadius,
											left: value,
										},
									});
								}
							}}
						/>
						<TextControl
							type="number"
							value={borderRadius.right}
							help={__('Right', 'dlm-buttons')}
							onChange={(value) => {
								if (borderRadius.sync) {
									handleSyncBorderRadius(value);
								} else {
									setAttributes({
										borderRadius: {
											...borderRadius,
											right: value,
										},
									});
								}
							}}
						/>
					</div>
					<Button
						className={borderRadius.sync ? 'is-pressed' : ''}
						data-attribute={'borderRadius'}
						icon={icons.sync}
						onClick={(e) => handleSyncPress(e)}
					/>
				</BaseControl>
			</PanelBody>
		</>
	);
}
