import './typography.scss';

import React from 'react';
import {
	PanelBody,
	BaseControl,
	Button,
	ButtonGroup,
	TextControl,
	SelectControl,
} from '@wordpress/components';

import { icons } from '../icons';
import { __ } from '@wordpress/i18n';

export default function TypographyControls({ attributes, setAttributes }) {
	const { font } = attributes;
	const weightOptions = [
		{ label: __('Normal', 'dlm-buttons'), value: 'normal' },
		{ label: __('Bold', 'dlm-buttons'), value: 'bold' },
		{ label: __('100', 'dlm-buttons'), value: '100' },
		{ label: __('200', 'dlm-buttons'), value: '200' },
		{ label: __('300', 'dlm-buttons'), value: '300' },
		{ label: __('400', 'dlm-buttons'), value: '400' },
		{ label: __('500', 'dlm-buttons'), value: '500' },
		{ label: __('600', 'dlm-buttons'), value: '600' },
		{ label: __('700', 'dlm-buttons'), value: '700' },
		{ label: __('800', 'dlm-buttons'), value: '800' },
		{ label: __('900', 'dlm-buttons'), value: '900' },
	];

	const transformOptions = [
		{ label: __('Default', 'dlm-buttons'), value: 'none' },
		{ label: __('Uppercase', 'dlm-buttons'), value: 'uppercase' },
		{ label: __('Lowercase', 'dlm-buttons'), value: 'lowercase' },
		{ label: __('Capitalize', 'dlm-buttons'), value: 'capitalize' },
	];

	const fontOptions = [
		{ label: __('Inherit', 'dlm-buttons'), value: 'inherit' },
		{ label: __('Arial (sans-serif)', 'dlm-buttons'), value: 'arial' },
		{ label: __('Verdana (sans-serif)', 'dlm-buttons'), value: 'verdana' },
		{ label: __('Tahoma (sans-serif)', 'dlm-buttons'), value: 'tahoma' },
		{ label: __('Impact (sans-serif)', 'dlm-buttons'), value: 'impact' },
		{ label: __('Didot (serif)', 'dlm-buttons'), value: 'didot' },
		{ label: __('Georgia (serif)', 'dlm-buttons'), value: 'georgia' },
		{ label: __('Courier (monospace)', 'dlm-buttons'), value: 'courier' },
		{ label: __('Monaco (monospace)', 'dlm-buttons'), value: 'monaco' },
		{ label: __('Luminari (fantasy)', 'dlm-buttons'), value: 'luminari' },
	];

	const handleFontAfterClick = (e) => {
		setAttributes({ font: { ...font, after: e.target.value } });
	};

	const handleResetClick = () => {
		setAttributes({
			font: {
				fontFamily: 'sans-serif',
				fontSize: 16,
				after: 'px',
			},
		});
	};

	const handleFontSizeChange = (e) => {
		if (e < 0) return;
		setAttributes({ font: { ...font, fontSize: e } });
	};

	return (
		<>
			<PanelBody
				title={__('Typography', 'dlm-buttons')}
				icon={icons.typography}
				className="dlm-buttons-panel"
				initialOpen={false}
			>
				<BaseControl label={__('Font Family', 'dlm-buttons')}>
					<SelectControl
						value={font.fontFamily}
						options={fontOptions}
						onChange={(e) =>
							setAttributes({ font: { ...font, fontFamily: e } })
						}
					/>
				</BaseControl>
				<div className="dlm-buttons-column-controls">
					<BaseControl label={__('Weight', 'dlm-buttons')}>
						<SelectControl
							options={weightOptions}
							value={font.fontWeight}
							onChange={(e) =>
								setAttributes({
									font: { ...font, fontWeight: e },
								})
							}
						/>
					</BaseControl>
					<BaseControl label={__('Transform', 'dlm-buttons')}>
						<SelectControl
							options={transformOptions}
							value={font.textTransform}
							onChange={(e) =>
								setAttributes({
									font: { ...font, textTransform: e },
								})
							}
						/>
					</BaseControl>
				</div>
				<BaseControl className="dlm-buttons-controls">
					<div className="dlm-buttons-unit-controls">
						<BaseControl.VisualLabel>
							{__('Font Size', 'dlm-buttons')}
						</BaseControl.VisualLabel>
						<ButtonGroup>
							<Button
								className={
									'px' == font.after ? 'is-pressed' : ''
								}
								value="px"
								onClick={handleFontAfterClick}
								isSmall
							>
								px
							</Button>
							<Button
								className={
									'em' == font.after ? 'is-pressed' : ''
								}
								value="em"
								onClick={handleFontAfterClick}
								isSmall
							>
								em
							</Button>
							<Button
								className={
									'%' == font.after ? 'is-pressed' : ''
								}
								value="%"
								onClick={handleFontAfterClick}
								isSmall
							>
								%
							</Button>
						</ButtonGroup>
					</div>
					<div className="dlm-buttons-input-controls">
						<TextControl
							placeholder={font.fontSize}
							value={font.fontSize}
							onChange={(e) => handleFontSizeChange(e)}
							type="number"
						/>
						<Button onClick={handleResetClick} isSmall isSecondary>
							Reset
						</Button>
					</div>
				</BaseControl>
			</PanelBody>
		</>
	);
}
