const { useEffect, useState } = wp.element;
const { useBlockProps } = wp.blockEditor;
import { v4 as uuidv4 } from 'uuid';

import ButtonInspectorControls from './ButtonInspectorControls/ButtonInspectorControls';
import TemplateButton from './TemplateButton/TemplateButton';
import DownloadButton from './DownloadButton/DownloadButton';
import ButtonsToolbar from './ButtonsToolbar/ButtonsToolbar';

const Edit = (props) => {
	const { attributes, setAttributes } = props;
	const [downloads, setDownloads] = useState(false);
	const [templates, setTemplates] = useState(false);
	const blockProps = useBlockProps({
		className: 'dlm-buttons',
	});
	const { buttonId } = attributes;
	useEffect(() => {
		setAttributes({ buttonId: uuidv4() });
	}, []);

	function fetchDownloads() {
		fetch(`${dlmButtonVars.restURL}wp/v2/dlm_download/`)
			.then((res) => res.json())
			.then((downloads) => {
				//set_downloads(downloads);
				let preOptions = [
					{
						value: 0,
						label: 'Select a download',
					},
				];
				downloads.forEach((download) => {
					preOptions.push({
						value: download.id,
						label: download.title.rendered,
					});
				});
				setDownloads(preOptions);
			});
	}

	async function fetchTemplates() {
		let res = await fetch(
			`${dlmButtonVars.restURL}wp/v2/dlm_buttons/templates`
		);
		let templates = await res.json();

		let templatesArray = [
			{
				value: 'none',
				label: 'Select a template',
			},
		];
		templates.forEach((template) => {
			templatesArray.push({
				value: template.name,
				label: template.name,
			});
		});
		setTemplates(templatesArray);
	}

	async function fetchTemplate(template) {
		let res = await fetch(
			`${dlmButtonVars.restURL}wp/v2/dlm_buttons/templates`
		);
		let templates = await res.json();
		let filteredTemplate = templates.filter((t) => t.name == template);
		setAttributes({ templateConfig: filteredTemplate[0] });
	}

	useEffect(() => {
		fetchDownloads();
		fetchTemplates();
	}, []);

	useEffect(() => {
		if ('none' == attributes.template) return;
		fetchTemplate(attributes.template);
	}, [attributes.template]);

	return (
		<>
			<ButtonsToolbar
				attributes={attributes}
				setAttributes={setAttributes}
			/>
			<ButtonInspectorControls
				attributes={attributes}
				setAttributes={setAttributes}
				downloads={downloads}
				templates={templates}
			/>
			<div
				{...blockProps}
				style={{ justifyContent: attributes.alignment }}
			>
				<>
					{attributes.template !== 'none' ? (
						<TemplateButton
							template={attributes.template}
							config={attributes.templateConfig}
						/>
					) : (
						<DownloadButton
							attributes={attributes}
							setAttributes={setAttributes}
							buttonId={buttonId}
						/>
					)}
				</>
			</div>
		</>
	);
};
export default Edit;
