<?php

namespace ElementorDLMButtons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class DLM_Buttons_Elementor_Widget extends \Elementor\Widget_Base {

	public function get_name() {
		return 'dlm_buttons_elementor';
	}

	public function get_title() {
		return apply_filters( 'dlm_buttons_elementor_name', esc_html__( 'DLM Button', 'dlm-buttons' ));
	}

	public function get_icon() {
		return 'eicon-elementor-square';
	}

	public function get_categories() {
		return array( 'general' );

	}

	public function get_downloads() {
		$downloads       = download_monitor()->service( 'download_repository' )->retrieve( array(
			'orderby' => 'title',
			'order'   => 'ASC'
		) );
		$downloads_array = array( 'none' => esc_html__( 'None', 'dlm-buttons' ) );
		if ( ! empty( $downloads ) ) {
			/** @var DLM_Download $download */
			foreach ( $downloads as $download ) {
				$downloads_array[ $download->get_id() ] = $download->get_title();
			}
		}
		return $downloads_array;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Content', 'dlm-buttons' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'dlm_download_select',
			array(
				'label'   => esc_html__( 'Select Download', 'dlm-buttons' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => $this->get_downloads(), // will be loaded through ajax
				'default' => 'none',
			)
		);

		// $this->add_control(
		// 	'dlm_version_select',
		// 	array(
		// 		'label'   => esc_html__( 'Select Version', 'dlm-buttons' ),
		// 		'type'    => \Elementor\Controls_Manager::TEXT,
		// 		'default' => '',
		// 		'placeholder' => esc_html__( 'Select Version', 'dlm-buttons' ),
		// 	)
		// );

		$this->add_control(
			'text',
			[
				'label' => esc_html__( 'Text', 'dlm-buttons' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'default' => esc_html__( 'Download', 'dlm-buttons' ),
				'placeholder' => esc_html__( 'Download', 'dlm-buttons' ),
			]
		);

		$this->add_control(
			'align',
			[
				'label' => esc_html__( 'Alignment', 'dlm-buttons' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left'    => [
						'title' => esc_html__( 'Left', 'dlm-buttons' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'dlm-buttons' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'dlm-buttons' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'dlm-buttons' ),
						'icon' => 'eicon-text-align-justify',
					],
				],
				'default' => '',
			]
		);

		$this->add_control(
			'size',
			[
				'label' => esc_html__( 'Size', 'dlm-buttons' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'sm',
				'options' =>  [
					'xs' => esc_html__( 'Extra Small', 'dlm-buttons' ),
					'sm' => esc_html__( 'Small', 'dlm-buttons' ),
					'md' => esc_html__( 'Medium', 'dlm-buttons' ),
					'lg' => esc_html__( 'Large', 'dlm-buttons' ),
					'xl' => esc_html__( 'Extra Large', 'dlm-buttons' ),
				],
				'style_transfer' => true,
			]
		);

		$this->add_control(
			'selected_icon',
			[
				'label' => esc_html__( 'Icon', 'dlm-buttons' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'skin' => 'inline',
				'label_block' => false,
			]
		);

		$this->add_control(
			'icon_position',
			[
				'label' => esc_html__( 'Icon Position', 'dlm-buttons' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'left',
				'options' => [
					'left' => esc_html__( 'Before', 'dlm-buttons' ),
					'right' => esc_html__( 'After', 'dlm-buttons' ),
				],
				'condition' => [
					'selected_icon[value]!' => '',
				],
			]
		);

		$this->add_control(
			'icon_indent',
			[
				'label' => esc_html__( 'Icon Spacing', 'dlm-buttons' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 50,
					],
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'DLM Button', 'dlm-buttons' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->start_controls_tabs( 'tabs_dlm_button_style' );

		$this->start_controls_tab(
			'tab_dlm_button_normal',
			[
				'label' => esc_html__( 'Normal', 'dlm-buttons' ),
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label' => esc_html__( 'Text Color', 'dlm-buttons' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '',
				'selectors'=> ['{{WRAPPER}} .dlm-buttons-container .dlm-download-button, {{WRAPPER}} .dlm-buttons-container i' => 'fill: {{VALUE}}; color: {{VALUE}};'],
			]
		);

		$this->add_group_control(
			'background',
			[
				'name' => 'dlm_button_background',
				'label' => esc_html__( 'Background', 'dlm-buttons' ),
				'types' => [ 'classic' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .dlm-download-button',
				'fields_options' => [
					'background' => [
						'default' => 'classic',
					],
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => esc_html__( 'Hover', 'dlm-buttons' ),
			]
		);

		$this->add_control(
			'hover_color',
			[
				'label' => esc_html__( 'Text Color', 'dlm-buttons' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dlm-download-button:hover, {{WRAPPER}} .dlm-download-button:focus' => 'color: {{VALUE}};',
					'{{WRAPPER}} .dlm-download-button:hover i, {{WRAPPER}} .dlm-download-button:focus i' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			'background',
			[
				'name' => 'button_background_hover',
				'label' => esc_html__( 'Background', 'dlm-buttons' ),
				'types' => [ 'classic' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .dlm-download-button:hover, {{WRAPPER}} .dlm-download-button:focus',
				'fields_options' => [
					'background' => [
						'default' => 'classic',
					],
				],
			]
		);

		$this->add_control(
			'button_hover_border_color',
			[
				'label' => esc_html__( 'Border Color', 'elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'condition' => [
					'border_border!' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .dlm-download-button:hover, {{WRAPPER}} .dlm-download-button:focus' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_group_control(
			'border',
			[
				'name' => 'border',
				'selector' => '{{WRAPPER}} .dlm-download-button',
				'separator' => 'before',
			]
		);

		$this->add_control(
			'border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'dlm-buttons' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .dlm-download-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'text_padding',
			[
				'label' => esc_html__( 'Padding', 'dlm-buttons' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .dlm-download-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);

		$this->end_controls_section();


	}

	protected function render() {
		$settings   = $this->get_settings_for_display();
		$block_id = $this->get_id();
		$this->add_render_attribute( 'button', 'style', 'display: flex;' );
		$this->add_render_attribute( 'button', 'style', 'align-items: center;' );
		$this->add_render_attribute( 'button', 'class', 'dlm-download-button' );
		if ( ! empty( $settings['size'] ) ) {
			$this->add_render_attribute( 'button', 'class', 'dlm-button-size-' . $settings['size'] );
		}
		$download_id = $settings['dlm_download_select'];
		$is_icon = $settings['selected_icon']['value'] != '' ? true : false;
		$svg_icon = isset( $settings['selected_icon'] ) && $settings['selected_icon']['library'] == 'svg' ? true : false;
		if ( 'none' != $download_id ) {
			$download = download_monitor()->service( 'download_repository' )->retrieve_single( $download_id );
			?>
			<style>
				.dlm-buttons-container-<?php echo esc_attr( $block_id ); ?> {
					display:flex;
					align-items: center;
					justify-content: <?php echo esc_attr( $settings['align'] ); ?>;
				}

				.dlm-buttons-container-<?php echo esc_attr( $block_id ); ?> .dlm-download-button {
					display:flex;
					align-items: center;
				}

				.dlm-download-button.dlm-button-size-xs {
					font-size: 10px;
				}

				.dlm-download-button.dlm-button-size-sm {
					font-size: 12px;
				}

				.dlm-download-button.dlm-button-size-md {
					font-size: 14px;
				}

				.dlm-download-button.dlm-button-size-lg {
					font-size: 18px;
				}

				.dlm-download-button.dlm-button-size-xl {
					font-size: 24px;
				}
			</style>
			<div style="display:flex" class="<?php echo "dlm-buttons-container-$block_id dlm-buttons-container" ?>">
			<a href="<?php echo $download->the_download_link() ?>"  <?php $this->print_render_attribute_string( 'button' ); ?> class="dlm-download-button">
				<?php if($is_icon && $settings['icon_position'] == 'left'): ?>
					<?php if( $svg_icon ): ?>
						<div style="margin-right:<?php echo esc_attr( $settings['icon_indent']['size'] ); ?>px; display:flex;">
							<?php \Elementor\Icons_Manager::render_icon( $settings['selected_icon'] ); ?>
						</div>
					<?php else: ?>
						<i class="<?php echo esc_attr( $settings['selected_icon']['value'] ); ?>" <?php echo esc_attr( $settings['selected_icon']['library'] ); ?> style="margin-right:<?php echo esc_attr( $settings['icon_indent']['size'] ); ?>px"></i>
					<?php endif; ?>
				<?php endif; ?>
				<?php echo esc_html( $settings['text'] ) ?>
				<?php if($is_icon && $settings['icon_position'] == 'right'): ?>
					<?php if( $svg_icon ): ?>
						<div style="margin-left:<?php echo esc_attr( $settings['icon_indent']['size'] ); ?>px; display:flex;">
							<?php \Elementor\Icons_Manager::render_icon( $settings['selected_icon'] ); ?>
						</div>
					<?php else: ?>
						<i class="<?php echo esc_attr( $settings['selected_icon']['value'] ); ?>" <?php echo esc_attr( $settings['selected_icon']['library'] ); ?> style="margin-left:<?php echo esc_attr( $settings['icon_indent']['size'] ); ?>px"></i>
					<?php endif; ?>
			<?php endif; ?>
			</a>

		</div><?php
		}

	}

	protected function content_template() {
		?>
		<#
		view.addRenderAttribute( 'text', 'class', 'elementor-button-text' );
		view.addRenderAttribute( 'align', 'style', `display:flex;justify-content:${settings.align}` );
		view.addRenderAttribute( 'button', 'class', `dlm-download-button` );
		if( settings.size ) {
			view.addRenderAttribute( 'button', 'class', `dlm-button-size-${settings.size}` );
		}
		view.addInlineEditingAttributes( 'text', 'align' );
		var iconHTML = elementor.helpers.renderIcon( view, settings.selected_icon, { 'aria-hidden': true }, 'i' , 'object' ),
			migrated = elementor.helpers.isIconMigrated( settings, 'selected_icon' );
		let block_id = view.getID();
		#>

		<style>
			.dlm-buttons-container-{{{block_id}}} {
					display:flex;
					align-items: center;
					justify-content: {{{ settings.align }}};
			}

			.dlm-buttons-container-{{{block_id}}} .dlm-download-button {
				display: flex;
    			align-items: center;
			}

			.dlm-download-button.dlm-button-size-xs {
					font-size: 10px;
			}
			.dlm-download-button.dlm-button-size-sm {
					font-size: 12px;
			}

			.dlm-download-button.dlm-button-size-md {
				font-size: 14px;
			}
			.dlm-download-button.dlm-button-size-lg {
				font-size: 18px;
			}
			.dlm-download-button.dlm-button-size-xl {
				font-size: 24px;
			}

		</style>
		<div class="dlm-buttons-container-{{{ block_id }}} dlm-buttons-container">

			<a  {{{ view.getRenderAttributeString( 'button' ) }}}>
				<# if ( settings.selected_icon && settings.icon_position == 'left' ) { #>
					<# if( iconHTML.rendered ) { #>
						<div  style="margin-right:{{{ settings.icon_indent.size}}}px; display:flex;">
							{{{ iconHTML.value }}}
						</div>
					<# } else { #>
					<i class="{{{ settings.selected_icon.library }}} {{{settings.selected_icon.value}}}" style="margin-right:{{{ settings.icon_indent.size}}}px" aria-hidden="true"></i>
					<# } #>
				<# } #>
				{{{ settings.text }}}
				<# if(settings.selected_icon && settings.icon_position == 'right' ) { #>
					<# if( iconHTML.rendered ) { #>
						<div style="margin-left:{{{ settings.icon_indent.size}}}px; display:flex;">
							{{{ iconHTML.value }}}
						</div>
					<# } else { #>
						<i class="{{{ settings.selected_icon.library }}} {{{settings.selected_icon.value}}}" style="margin-left:{{{ settings.icon_indent.size}}}px" aria-hidden="true"></i>
					<# } #>
			<# } #>
			</a>


		</div>
		<?php
	}

}